pub fn admin_plugin_enabled(ctx: &AuthContext<impl AuthSchema>) -> boolExpand description
Whether the admin plugin is active for this auth instance.
pub fn admin_plugin_enabled(ctx: &AuthContext<impl AuthSchema>) -> boolWhether the admin plugin is active for this auth instance.